===========
Gewebehaken
===========

A framework to provide HTTP endpoints for incoming webhooks.

Currently supported:

- GitLab
- Twitter (via Zapier)

:Copyright: 2015-2022 `Jochen Kupperschmidt <https://homework.nwsnet.de/>`_
:License: MIT, see LICENSE for details.


Code Status
===========

|badge_github-actions_test|

.. |badge_github-actions_test| image:: https://github.com/homeworkprod/gewebehaken/actions/workflows/test.yml/badge.svg
   :alt: Testing Status
   :target: https://github.com/homeworkprod/gewebehaken/actions/workflows/test.yml


Requirements
============

- Python 3.7+
- Dependencies: blinker_, Flask_, Werkzeug_

.. _blinker: https://blinker.readthedocs.io/
.. _Flask: https://palletsprojects.com/p/flask/
.. _Werkzeug: https://palletsprojects.com/p/werkzeug/
